@@ -45,6 +45,7 @@ OC.L10N.register(
     "Description" : "Descripción",
     "right" : "Derecha",
     "Jump to next article" : "Salta a l'artículu siguiente",
+    "left" : "esquierda",
     "Jump to previous article" : "Salta a l'artículu previu",
     "Toggle star article" : "Marcar como favoritu",
     "Toggle keep current article unread" : "Marcar como non lleíu",
@@ -81,6 +82,8 @@ OC.L10N.register(
     "Rename" : "Renomar",
     "Menu" : "Menú",
     "Unpin from top" : "Defixar de lo cimero",
+    "Newest first" : "Lo más nuevo",
+    "Oldest first" : "Lo más vieyo",
     "Delete" : "Desaniciar",
     "Dismiss" : "Encaboxar",
     "Collapse" : "Contrayer",
