@@ -1,16 +1,27 @@
 OC.L10N.register(
     "news",
     {
+    "Saved" : "Wedi'u cadw",
     "Download" : "Llwytho i lawr",
     "Close" : "Cau",
+    "Subscribe" : "Tanysgrifio",
     "by" : "gan",
+    "from" : "oddi wrth",
     "Description" : "Disgrifiad",
     "Refresh" : "Adnewyddu",
     "Web address" : "Cyfeiriad gwe",
     "Folder" : "Plygell",
+    "New folder" : "Ffolder newydd",
+    "Go back" : "Nôl",
+    "Credentials" : "Credentials",
     "Username" : "Enw defnyddiwr",
     "Password" : "Cyfrinair",
+    "Create" : "Creu",
     "Rename" : "Ailenwi",
+    "Mark read" : "Marcio wedi'i ddarllen",
+    "Newest first" : "Diweddaraf gyntaf",
+    "Oldest first" : "Hynaf gyntaf",
+    "Delete" : "Dileu",
     "Settings" : "Gosodiadau",
     "Import" : "Mewnforio",
     "Export" : "Allforio",
