@@ -16,10 +16,12 @@ OC.L10N.register(
     "Folder" : "ថត",
     "New folder" : "ថត​ថ្មី",
     "Folder name" : "ឈ្មោះ​ថត",
+    "Credentials" : "Credentials",
     "Username" : "ឈ្មោះ​អ្នកប្រើ",
     "Password" : "ពាក្យសម្ងាត់",
     "Create" : "បង្កើត",
     "Rename" : "ប្ដូរ​ឈ្មោះ",
+    "Delete" : "លុប",
     "Collapse" : "បត់បង្រួម",
     "Starred" : "បាន​ដាក់​ផ្កាយ",
     "Unread articles" : "អត្ថបទ​ដែល​មិន​ទាន់​អាន",
