@@ -80,6 +80,10 @@ OC.L10N.register(
     "Undo delete feed" : "Desfazer apagar a feed",
     "Rename" : "Renomear",
     "Menu" : "Menu",
+    "Mark read" : "Marcar como lido",
+    "Newest first" : "Recentes primeiro",
+    "Oldest first" : "Antigos primeiro",
+    "Delete" : "Apagar",
     "Dismiss" : "Rejeitar",
     "Collapse" : "Expandir",
     "Deleted folder" : "Apagar pasta",
