@@ -11,10 +11,12 @@ OC.L10N.register(
     "Folder" : "قىسقۇچ",
     "New folder" : "يېڭى قىسقۇچ",
     "Folder name" : "قىسقۇچ ئاتى",
+    "Credentials" : "Credentials",
     "Username" : "ئىشلەتكۈچى ئاتى",
     "Password" : "ئىم",
     "Create" : "قۇر",
     "Rename" : "ئات ئۆزگەرت",
+    "Delete" : "ئۆچۈر",
     "Starred" : "يۇلتۇزلۇق",
     "Settings" : "تەڭشەكلەر",
     "Import" : "ئەكىر",
