@@ -10,7 +10,7 @@ OC.L10N.register(
     "Can not add folder: Exists already" : "Неможливо додати теку: вона вже існує",
     "Disable this if you run a custom updater such as the Python updater included in the app" : "Вимкніть, якщо збираєтеся використовувати інший механізм оновлень, наприклад, Python updater, включений в поставку цього додатка",
     "Purge interval" : "Очистити оновлення",
-    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Мінімальна кількість секунд, після чого видалені стрічки й каталоги будуть видалені з бази даних; значення менш ніж 60 секунд будуе проігноровано",
+    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Мінімальна кількість секунд, після чого стрічки й каталоги, які було вилучено, буде вилучено з бази даних; значення менш ніж 60 секунд буде проігноровано",
     "Maximum read count per feed" : "Максимальна кількість статей для стрічки",
     "Maximum redirects" : "Максимум перенаправлень",
     "How many redirects the feed fetcher should follow" : "Скільки перенаправлень повинен обробляти завантажувач стрічки",
@@ -72,17 +72,17 @@ OC.L10N.register(
     "New Folder" : "Нова тека",
     "Create" : "Створити",
     "Explore" : "Дослідити",
-    "Deleted feed" : "Видалена стрічка",
-    "Undo delete feed" : "Відмінити видалення стрічки",
+    "Deleted feed" : "Вилучена стрічка",
+    "Undo delete feed" : "Скасувати вилучення стрічки",
     "Rename" : "Перейменувати",
     "Menu" : "Меню",
     "Newest first" : "Новіші попереду",
     "Oldest first" : "Старіші попереду",
-    "Delete" : "Видалити",
+    "Delete" : "Вилучити",
     "Dismiss" : "Припинити",
     "Collapse" : "Згорнути",
-    "Deleted folder" : "Видалені теки",
-    "Undo delete folder" : "Відмінити видалення теки",
+    "Deleted folder" : "Вилучені теки",
+    "Undo delete folder" : "Скасувати вилучення теки",
     "Starred" : "Помічені зірочкою",
     "Unread articles" : "Непрочитані статті",
     "All articles" : "Всі статті",
